==> SyL-0.10.0.tar.gz: SyL/include/framework/View/SyL_ViewJson.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ViewJson.php,v 1.6 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * Jsonӥ塼饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ViewJson.php,v 1.6 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ViewJson extends SyL_View
{
    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function SyL_ViewJson(&$dm)
    {
        parent::SyL_View($dm);
        // ƥĥפ򥻥å
        $this->setContentType('application/json; charset=' . SYL_ENCODE_AJAX);
    }

    /**
     * HTML󥰼¹
     * 
     * @access public
     */
    function render()
    {
        if ($this->dm->getActionName() != '') {
            // ѥ᡼ϡJson֥Ȥ򥻥å
            if (!function_exists('json_encode')) {
                include_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilJson.php';
            }
            $values     =& $this->getActionValues();
            $javascript = json_encode($values);
            // JavaScirpt
            $this->setRender($javascript);
        }
    }
}

?>

==> SyL-0.11.0.tar.gz: SyL/include/framework/View/SyL_ViewJson.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ViewJson.php,v 1.7 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * Jsonӥ塼饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ViewJson.php,v 1.7 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ViewJson extends SyL_View
{
    /**
     * HTML󥰼¹
     * 
     * @access public
     */
    function render()
    {
        // ƥĥפ򥻥å
        $this->setContentType('application/json; charset=' . SYL_ENCODE_AJAX);

        if ($this->context->getActionName() != '') {
            // ѥ᡼ϡJson֥Ȥ򥻥å
            if (!function_exists('json_encode')) {
                include_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilJson.php';
            }
            $values     =& $this->getActionValues();
            $javascript = json_encode($values);
            // JavaScirpt
            $this->setRender($javascript);
        }
    }
}

?>
